@@ -44,8 +44,7 @@ from snowflake.connector.errorcode import (
     ER_OCSP_RESPONSE_STATUS_UNSUCCESSFUL,
 )
 from snowflake.connector.errors import RevocationCheckError
-from snowflake.connector.ocsp_snowflake import SnowflakeOCSP
-from snowflake.connector.ssd_internal_keys import ret_wildcard_hkey
+from snowflake.connector.ocsp_snowflake import SnowflakeOCSP, generate_cache_key
 
 with warnings.catch_warnings():
     warnings.simplefilter("ignore")
@@ -80,12 +79,6 @@ class SnowflakeOCSPAsn1Crypto(SnowflakeOCSP):
         "sha512": hashes.SHA3_512,
     }
 
-    WILDCARD_CERTID = None
-
-    def __init__(self, **kwargs):
-        super().__init__(**kwargs)
-        self.WILDCARD_CERTID = self.encode_cert_id_key(ret_wildcard_hkey())
-
     def encode_cert_id_key(self, hkey):
         issuer_name_hash, issuer_key_hash, serial_number = hkey
         issuer_name_hash = OctetString.load(issuer_name_hash)
@@ -103,12 +96,8 @@ class SnowflakeOCSPAsn1Crypto(SnowflakeOCSP):
         )
         return cert_id
 
-    def decode_cert_id_key(self, cert_id):
-        return (
-            cert_id["issuer_name_hash"].dump(),
-            cert_id["issuer_key_hash"].dump(),
-            cert_id["serial_number"].dump(),
-        )
+    def decode_cert_id_key(self, cert_id: CertId) -> tuple[bytes, bytes, bytes]:
+        return generate_cache_key(cert_id)
 
     def decode_cert_id_base64(self, cert_id_base64):
         return CertId.load(b64decode(cert_id_base64))
@@ -365,7 +354,6 @@ class SnowflakeOCSPAsn1Crypto(SnowflakeOCSP):
         try:
             if cert_status == "good":
                 self._process_good_status(single_response, cert_id, ocsp_response)
-                SnowflakeOCSP.OCSP_CACHE.update_cache(self, cert_id, ocsp_response)
             elif cert_status == "revoked":
                 self._process_revoked_status(single_response, cert_id)
             elif cert_status == "unknown":
